# uBlock

The uBlock ad blocking web extension is contained here.

# Building

- Install [Node](https://nodejs.org), cd into the project root and run:
- Copy `.env.template` to a `.env` file and fill in the env vars accordingly

## For production

- `npm install` - install dependencies.
- `npm run subscriptions` - download and configure manifest v3 subscriptions and rulesets.
- `npm run rules` - generate mv2 rules to include in the extension (relies on the filter lists downloaded using `npm run subscriptions`).
- `npm run build` creates the exploded extensions in the `/bundles/&lt;browser&gt;` directories.

# Upgrading EWE

In order to upgrade EWE upgrade the npm dependency using `npm install @eyeo/webext-ad-filtering-solution`.

# Development

Directory layout:

- `/src` - source files for the extension (no build required)
- `/test` - Jest test files
- `/manifest` - browser specific manifest.json files
- `/build` - scripts that support building the extension for app store submission
- `/dist` - build products are produced here

The project uses Jest for unit tests, eslint with standard recommended rules, and Prettier for formatting.

Normal development workflow:

- `npm run subscriptions` - update subscriptions and rulesets (only needs to be done daily/weekly)
- `npm run rules` - update hiding rules (only needs to be done daily/weekly when subscriptions is updated)
- `npm run dev` - dynamically builds the extension
- `web-ext run` - in the `dist` directory watches and hot reloads the extension in Firefox.
- `npm test` - to run unit tests.

To create a deployment

- `npm run subscriptions` - update subscriptions and rulesets
- `node run build` - to build extensions bundles for all supported browsers

To create assets for release
- update the version in the package.json, and the manifest files in the `/manifest` directory
- perform a clean install
- add the updated assets to the repo
- run the following commands:
  - `npm run subscriptions`
  - `npm run rules`
  - `npm run build`

## Sentry

We use Sentry to report production runtime errors. You can enable it in development too by setting the `VITE_SENTRY_DSN`
and `VITE_NODE_ENV` variables in your local `.env` file.  
Make sure that `VITE_NODE_ENV` is set to `dev` so the errors of your local build are not reported as production errors.  

The dashboard for the project is available [here](https://eyeo.sentry.io/projects/ublock/?project=4506632517517312).  
You can find detailed technical explanations about Sentry in the [description of the pull request that introduced it](https://github.com/betafish-inc/ublock/pull/7).

### Sourcemap upload

To better understand the errors, sourcemaps must be uploaded to sentry. This process happens automatically when running `npm run build`.  
If the user has not set up the sourcemap uploader first, they will be prompted to log in to Sentry to retrieve an auth token that will be stored locally in their repository.

## Eyeometry

We use Eyeometry as a mechanism for reporting. In order to activate it, we have to pass some parameters to the ewe sdk's start call. 
Two properties are required. The url for the server configured for uBlock and the bearer token. These are stored locally in the same way as the Sentry variables. 

`VITE_EYEOMETRY_URL` is the url of the server where requests are sent. `VITE_EYEOMETRY_BEARER` is also required for requests. 

## Versioning 

`YY.QUARTER.INCREMENTAL`
Quarter is zero based. For an example, the second update to the extension in the second quarter of 2025:
`25.1.2`