import { http, HttpResponse } from 'msw'
import { expect, test } from 'vitest'
import { server } from '../vitest.setup.js';

import {
  generateUserId,
  parseUri,
  ping,
} from "../src/background/utils/utils.js";

test("id generated", () => {
  expect(generateUserId().length).toBe(16);
});

test("parse url", () => {
  const url = parseUri("https://host:8080/path/to/target");
  expect(url.host).toBe("host:8080");
  expect(url.hostname).toBe("host");
  expect(url.port).toBe("8080");
});

test("ping", async () => {
  server.use(http.post("https://ping.ublock.org/api/stats", () => {
    return HttpResponse.json({ data: "Hello World!" });
  }));

  const response = await ping({});
  const result = await response.json();

  expect(result.data).toEqual("Hello World!");
});
